@@ -5,6 +5,7 @@ from .overlay import overlay
 #from .compress import compress
 from .topng import topng
 from .addbg import addbg
+from .instagram import instagram
 
 CONTEXT_SETTINGS = dict(
         help_option_names = [
@@ -19,7 +20,7 @@ def main():
 
 
 
-
+main.add_command(instagram)
 main.add_command(split)
 main.add_command(overlay)
 main.add_command(topng)
